@@ -12,9 +12,6 @@ from anki.lang import _
 class Preferences(QDialog):
 
     def __init__(self, mw):
-        if not mw.col:
-            showInfo(_("Please open a profile first."))
-            return
         QDialog.__init__(self, mw, Qt.Window)
         self.mw = mw
         self.prof = self.mw.pm.profile
